==> librepcb-0.1.7-source.zip: librepcb-0.1.7/libs/librepcb/core/project/board/boardairwiresbuilder.h <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBREPCB_CORE_BOARDAIRWIRESBUILDER_H
#define LIBREPCB_CORE_BOARDAIRWIRESBUILDER_H

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "../../types/point.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace / Forward Declarations
 ******************************************************************************/
namespace librepcb {

class Board;
class NetSignal;

/*******************************************************************************
 *  Class BoardAirWiresBuilder
 ******************************************************************************/

/**
 * @brief The BoardAirWiresBuilder class
 */
class BoardAirWiresBuilder final {
public:
  // Constructors / Destructor
  BoardAirWiresBuilder() = delete;
  BoardAirWiresBuilder(const BoardAirWiresBuilder& other) = delete;
  BoardAirWiresBuilder(const Board& board, const NetSignal& netsignal) noexcept;
  ~BoardAirWiresBuilder() noexcept;

  // General Methods
  QVector<QPair<Point, Point>> buildAirWires() const;

  // Operator Overloadings
  BoardAirWiresBuilder& operator=(const BoardAirWiresBuilder& rhs) = delete;

private:  // Data
  const Board& mBoard;
  const NetSignal& mNetSignal;
};

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace librepcb

#endif

==> librepcb-1.3.0-source.zip: librepcb-1.3.0/libs/librepcb/core/project/board/boardairwiresbuilder.h <==
/*
 * LibrePCB - Professional EDA for everyone!
 * Copyright (C) 2013 LibrePCB Developers, see AUTHORS.md for contributors.
 * https://librepcb.org/
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LIBREPCB_CORE_BOARDAIRWIRESBUILDER_H
#define LIBREPCB_CORE_BOARDAIRWIRESBUILDER_H

/*******************************************************************************
 *  Includes
 ******************************************************************************/
#include "../../types/point.h"

#include <QtCore>

/*******************************************************************************
 *  Namespace / Forward Declarations
 ******************************************************************************/
namespace librepcb {

class BI_NetLineAnchor;
class Board;
class NetSignal;

/*******************************************************************************
 *  Class BoardAirWiresBuilder
 ******************************************************************************/

/**
 * @brief The BoardAirWiresBuilder class
 */
class BoardAirWiresBuilder final {
public:
  // Constructors / Destructor
  BoardAirWiresBuilder() = delete;
  BoardAirWiresBuilder(const BoardAirWiresBuilder& other) = delete;
  BoardAirWiresBuilder(const Board& board, const NetSignal& netsignal) noexcept;
  ~BoardAirWiresBuilder() noexcept;

  // General Methods
  QVector<std::pair<const BI_NetLineAnchor*, const BI_NetLineAnchor*>>
      buildAirWires() const;

  // Operator Overloadings
  BoardAirWiresBuilder& operator=(const BoardAirWiresBuilder& rhs) = delete;

private:  // Data
  const Board& mBoard;
  const NetSignal& mNetSignal;
};

/*******************************************************************************
 *  End of File
 ******************************************************************************/

}  // namespace librepcb

#endif
